@@ -30,23 +30,23 @@
 #define CHARSETS_LIST           "mc.charsets"
 #define MC_MACRO_FILE           "mc.macros"
 
-#define FISH_PREFIX             "fish"
+#define VFS_SHELL_PREFIX        "shell"
 
-#define FISH_LS_FILE            "ls"
-#define FISH_EXISTS_FILE        "fexists"
-#define FISH_MKDIR_FILE         "mkdir"
-#define FISH_UNLINK_FILE        "unlink"
-#define FISH_CHOWN_FILE         "chown"
-#define FISH_CHMOD_FILE         "chmod"
-#define FISH_UTIME_FILE         "utime"
-#define FISH_RMDIR_FILE         "rmdir"
-#define FISH_LN_FILE            "ln"
-#define FISH_MV_FILE            "mv"
-#define FISH_HARDLINK_FILE      "hardlink"
-#define FISH_GET_FILE           "get"
-#define FISH_SEND_FILE          "send"
-#define FISH_APPEND_FILE        "append"
-#define FISH_INFO_FILE          "info"
+#define VFS_SHELL_LS_FILE       "ls"
+#define VFS_SHELL_EXISTS_FILE   "fexists"
+#define VFS_SHELL_MKDIR_FILE    "mkdir"
+#define VFS_SHELL_UNLINK_FILE   "unlink"
+#define VFS_SHELL_CHOWN_FILE    "chown"
+#define VFS_SHELL_CHMOD_FILE    "chmod"
+#define VFS_SHELL_UTIME_FILE    "utime"
+#define VFS_SHELL_RMDIR_FILE    "rmdir"
+#define VFS_SHELL_LN_FILE       "ln"
+#define VFS_SHELL_MV_FILE       "mv"
+#define VFS_SHELL_HARDLINK_FILE "hardlink"
+#define VFS_SHELL_GET_FILE      "get"
+#define VFS_SHELL_SEND_FILE     "send"
+#define VFS_SHELL_APPEND_FILE   "append"
+#define VFS_SHELL_INFO_FILE     "info"
 
 #define MC_EXTFS_DIR            "extfs.d"
 
