@@ -12,7 +12,11 @@
 
 /*** global variables defined in .c file *********************************************************/
 
-extern WDialog *midnight_dlg;
+extern GList *top_dlg;
+
+extern gboolean fast_refresh;
+
+extern WDialog *filemanager;
 
 /*** declarations of public functions ************************************************************/
 
@@ -28,6 +32,9 @@ int dialog_switch_process_pending (void);
 void dialog_switch_got_winch (void);
 void dialog_switch_shutdown (void);
 
+/* Redraw all dialogs */
+void do_refresh (void);
+
 void repaint_screen (void);
 void mc_refresh (void);
 void dialog_change_screen_size (void);
